# - AthenaLib -
[![pypi](https://img.shields.io/pypi/v/AthenaLib)](https://pypi.org/project/AthenaLib/) [![GitHub license](https://img.shields.io/github/license/DirectiveAthena/AthenaLib)](https://github.com/DirectiveAthena/VerSC-AthenaColor/blob/master/LICENSE) [![Discord](https://img.shields.io/discord/814599159926620160?color=maroon)](https://discord.gg/6JcDbhXkCH) [![Downloads](https://pepy.tech/badge/athenalib)](https://pepy.tech/project/athenalib)



--- 
## Package Details
#### Details and features 
- A library of Python modules for Directive Athena related Packages
- Used as a dependency on most, if not all, "*Athena...*" packages
  - An exception to these rules is [AthenaColor](https://github.com/DirectiveAthena/AthenaColor) as this package is "dependency-less"

#### Python Version
- Supported Python versions: **3.10**
  - Other older versions of Python are not currently supported. 
  - These older versions will probably not be supported by [@AndreasSas](https://github.com/AndreasSas) himself, but if you want to contribute to the project and make this package compatible with older versions of Python, Pull requests are always welcome.

---
## Documentation
Full documentation can be found at:
**[directiveathena.com](https://publish.obsidian.md/directiveathena/)** (redirect to Obsidian.md publish site)
(Reminder, the documentation is still under heavy development)

---
## Install
To install the package in your Python environment

```
pip install AthenaLib --upgrade
```

---

## Links 
Project files can be found at:    
- [GitHub Repo](https://github.com/DirectiveAthena/AthenaLib)     
- [Pypi link](https://pypi.org/project/AthenaLib/)    

---

## Disclaimer
With  *No Dependency*, the standard library is not counted as a dependency

---
Made By Andreas Sas,` 2022`